@@ -5,28 +5,28 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.14_02';
+our $VERSION = '0.14_03';
 $VERSION =~ tr/_//d;
 
-use Carp ();
-
-sub _warn {
-  if ($_[-1] =~ /\n\z/) {
-    my $arg = pop @_;
-    $arg =~ s/(.*) at [^\n]*? line [0-9]+\.?\n$/$1/s;
-    push @_, $arg;
-  }
-  warn &Carp::longmess;
+BEGIN {
+  require Carp;
+  $Carp::CarpInternal{ +__PACKAGE__ }++;
 }
 
+sub _warn { warn &_longmess }
+
 sub _die {
   die @_ if ref $_[0];
+  die &_longmess;
+}
+
+sub _longmess {
   if ($_[-1] =~ /\n\z/) {
     my $arg = pop @_;
     $arg =~ s/(.*) at [^\n]*? line [0-9]+\.?\n$/$1/s;
     push @_, $arg;
   }
-  die &Carp::longmess;
+  &Carp::longmess;
 }
 
 my %OLD_SIG;
@@ -93,9 +93,30 @@ emit the stack backtraces.
 Also, all uses of C<carp> and C<croak> are made verbose,
 behaving like C<cluck> and C<confess>.
 
-=head2 EXPORT
+=head1 METHODS
 
-Nothing at all is exported.
+L<Carp::Always> implements the following methods.
+
+=head2 import
+
+  Carp::Always->import()
+
+Enables L<Carp::Always>. Also triggered by statements like
+
+  use Carp::Always;
+  use Carp::Always 0.14;
+
+but not by
+
+  use Carp::Always ();    # does not invoke import()
+
+=head2 unimport
+
+  Carp::Always->unimport();
+
+Disables L<Carp::Always>. Also triggered with
+
+  no Carp::Always;
 
 =head1 ACKNOWLEDGMENTS
 
